==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_accounts.js <==
_me = frm_accounts.prototype;
function frm_accounts(){};

_me.__constructor = function() {
	var me = this;

	this._size(500);
	this._title('SETTINGS::ACCOUNTS');

	//Loadni pocatecni stav accountu
	this.__state = {};
	this.__otherAccounts = {};
	var aAccounts = dataSet.get('accounts');
	for (var i in aAccounts){
		var acc = clone(aAccounts[i]);
		this.__state[i] = 'old';
		if (acc['PRIMARY']){
			acc['id'] = i;
			this.__primaryAccount = acc;
		}
		else
			this.__otherAccounts[i] = acc;
	}

	this._draw ('frm_accounts','main', {enable_quota:(me.__primaryAccount.MBOX_QUOTA?true:false),disable_otheraccounts:GWOthers.getItem('RESTRICTIONS','disable_otheraccounts')==1,disable_changepass:GWOthers.getItem('RESTRICTIONS','disable_changepass')==1});

	this.x_btn_ok._onclick = function() {
		if (me.__saveItems())
			me._destruct();
	};

	if (this.maintab.other){
		this.maintab.other.x_add._onclick = function() {
			gui._create('edit_dialog', 'frm_edit_account', '','', [me, '__onOtherAccAdd']);
		};

		this.maintab.other.x_accountslist._ondblclick = this.maintab.other.x_edit._onclick = function() {
			var kokos = me.maintab.other.x_accountslist._getSelectedValue();
			if (kokos)
				gui._create('edit_dialog', 'frm_edit_account', '','', [me, '__onOtherAccEdit'], kokos['uid'], me.__otherAccounts[kokos['uid']]);
		};

		this.maintab.other.x_remove._onclick = function() {
			var kokos = me.maintab.other.x_accountslist._getSelectedValue();
			if (kokos) {
				me.maintab.other.x_accountslist._removeSelected();
				me.__state[kokos['uid']] = 'deleted';
			}
		};
	}

	this.__loadItems();
};

_me.__loadItems = function() {

	if (this.maintab.other){
		var other = [];
		for (var i in this.__otherAccounts)
			other.push({'uid':i,'account':i});

		this.maintab.other.x_accountslist._add(other);
	}

	if (this.maintab.primary.progress && this.__primaryAccount.MBOX_QUOTA && this.__primaryAccount.MBOX_USAGE){
		this.maintab.primary.progress._range(this.__primaryAccount.MBOX_QUOTA);
		this.maintab.primary.progress._value(this.__primaryAccount.MBOX_USAGE);
		
		var v = 0;
		if (this.__primaryAccount.MBOX_QUOTA)
			v = Math.ceil(this.__primaryAccount.MBOX_USAGE/(this.__primaryAccount.MBOX_QUOTA/100));

		this.maintab.primary.progress._title(v + '% (' + Math.ceil(this.__primaryAccount.MBOX_USAGE/1024,1)+' MB / ' +Math.ceil(this.__primaryAccount.MBOX_QUOTA/1024,1) + ' MB)');
	}
    
	this.maintab.primary.description._value(this.__primaryAccount['DESCRIPTION']);
	this.maintab.primary.fullname._value(this.__primaryAccount['FULLNAME']);
	this.maintab.primary.alternative._value(this.__primaryAccount['ALTERNATIVE']);
	
	this.maintab.primary.x_last_time._value(this.__primaryAccount['LAST_TIME']);
	this.maintab.primary.x_last_ip._value(this.__primaryAccount['LAST_IP']);
};

_me.__saveItems = function() {
	var update = false;
	var accounts = new wm_accounts;
	var primary = {};

    if (GWOthers.getItem('RESTRICTIONS','disable_otheraccounts')!=1)
		for (var sEmail in this.__state) {
			var aValues = this.__otherAccounts[sEmail];
			switch (this.__state[sEmail]) {
				case 'edited':
					aValues['aid'] = sEmail;
				case 'new':
					update = true;
					accounts.add(aValues, 'folders');
					dataSet.add('accounts', [sEmail], aValues);

                    var value = gui.frm_main.folders._value();
                        value.push(sEmail);
                    gui.frm_main.folders._value(value);

					break;

				case 'deleted':
					accounts.remove({'aid':sEmail},'accounts','','folders');
					dataSet.remove('accounts',[sEmail]);
					update = true;
					break;

				default:
					continue;
			}
		}

	var desc = this.maintab.primary.description._value();
	if (desc != this.__primaryAccount['DESCRIPTION'])
		primary['DESCRIPTION'] = desc;

	var fname = this.maintab.primary.fullname._value();
	if (fname != this.__primaryAccount['FULLNAME'])
		primary['FULLNAME'] = fname;

	var alternative = this.maintab.primary.alternative._value();
	if (alternative)
		primary['ALTERNATIVE'] = alternative;

	if (GWOthers.getItem('RESTRICTIONS','disable_changepass')!=1) {
		var pwd = this.maintab.primary.x_old_password._value();
	    var newpwd = this.maintab.primary.x_new_password._value();
	    var newpwdc = this.maintab.primary.x_new_password_conf._value();

		if (pwd || newpwd || newpwdc){
			if (!newpwd || newpwd != newpwdc){
				// TODO create some javascript alert window
				alert(getLang('ALERTS::INVALID_PASSWORD'));
				this.maintab.primary.x_old_password._focus();
				return false;
			}

			// encrypt password
			var rsa = new RSAKey();
			rsa.setPublic(auth.hashid({"username":this.__primaryAccount['USERNAME']}), '10001');

			primary['OLDPASSWORD'] = rsa.encrypt(pwd);
			primary['PASSWORD'] = rsa.encrypt(newpwd);
		}
	}

	if (count(primary) > 0){
		var aid = this.__primaryAccount['id'];

		for (var i in primary)
			dataSet.add('accounts', [aid,i], primary[i]);
			
		update = true;
		primary['aid'] = aid;

		accounts.add(primary, 'folders','',[this,'__save_handler']);
        this.x_btn_ok._disabled(true);
		return false;
	}

	if (update)
		gui.frm_main.folders._fill();

	return true;
};

_me.__save_handler = function (error){
	if (error){
		alert(getLang('ALERTS::INVALID_PASSWORD'));
		this.x_btn_ok._disabled(false);
	}
	else{
		gui.frm_main.folders._fill();
		this._destruct();
	}
};

_me.__onOtherAccEdit = function(aValues, sAccountID) {
	if (sAccountID) {
		for (var i in aValues)
			this.__otherAccounts[sAccountID][i] = aValues[i];
		if (this.__state[sAccountID] != 'new')
			this.__state[sAccountID] = 'edited';
	}
};

_me.__onOtherAccAdd = function(aValues) {
	var sAccountID = aValues['EMAIL'];
	if (!sAccountID)
		return;

	this.__otherAccounts[sAccountID] = aValues;

	if (this.__state[sAccountID] && this.__state[sAccountID] != 'new')
		this.__state[sAccountID] = 'edited';
	else
		this.__state[sAccountID] = 'new';

	this.maintab.other.x_accountslist._add([{'uid':sAccountID,'account':sAccountID}]);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_accounts.js <==
_me = frm_accounts.prototype;
function frm_accounts(){};

_me.__constructor = function() {
	var me = this;

	this._size(500,'',true);
	this._title('SETTINGS::ACCOUNTS');

	//Loadni pocatecni stav accountu
	this.__state = {};
	this.__otherAccounts = {};
	var aAccounts = dataSet.get('accounts');
	
	for (var i in aAccounts){
		var acc = clone(aAccounts[i]);
		this.__state[i] = 'old';
		if (acc['PRIMARY']){
			acc['id'] = i;
			this.__primaryAccount = acc;
		}
		else
		if (acc.TYPE != 'rss')
			this.__otherAccounts[i] = acc;
	}

	this._draw ('frm_accounts','main', {enable_quota:(me.__primaryAccount.MBOX_QUOTA?true:false),disable_otheraccounts:GWOthers.getItem('RESTRICTIONS','disable_otheraccounts')==1,disable_changepass:GWOthers.getItem('RESTRICTIONS','disable_changepass')==1});

	this.x_btn_ok._onclick = function() {
		if (me.__saveItems())
			me._destruct();
	};

	if (this.maintab.other){
		this.maintab.other.x_add._onclick = function() {
			gui._create('edit_dialog', 'frm_edit_account', '','', [me, '__onOtherAccAdd']);
		};

		this.maintab.other.x_accountslist._ondblclick = this.maintab.other.x_edit._onclick = function() {
			var kokos = me.maintab.other.x_accountslist._getSelectedValue();
			if (kokos)
				gui._create('edit_dialog', 'frm_edit_account', '','', [me, '__onOtherAccEdit'], kokos['uid'], me.__otherAccounts[kokos['uid']]);
		};

		this.maintab.other.x_remove._onclick = function() {
			var kokos = me.maintab.other.x_accountslist._getSelectedValue();
			if (kokos) {
				me.maintab.other.x_accountslist._removeSelected();
				me.__state[kokos['uid']] = 'deleted';
			}
		};
	}

	this.__loadItems();
};

_me.__loadItems = function() {

	if (this.maintab.other){
		var other = [];
		for (var i in this.__otherAccounts)
			other.push({'uid':i,'account':i});

		this.maintab.other.x_accountslist._add(other);
	}

	if (this.maintab.primary.progress && this.__primaryAccount.MBOX_QUOTA && this.__primaryAccount.MBOX_USAGE){
		this.maintab.primary.progress._range(this.__primaryAccount.MBOX_QUOTA);
		this.maintab.primary.progress._value(this.__primaryAccount.MBOX_USAGE);
		
		var v = 0;
		if (this.__primaryAccount.MBOX_QUOTA)
			v = Math.ceil(this.__primaryAccount.MBOX_USAGE/(this.__primaryAccount.MBOX_QUOTA/100));

		this.maintab.primary.progress._title(v + '% (' + Math.ceil(this.__primaryAccount.MBOX_USAGE/1024,1)+' MB / ' +Math.ceil(this.__primaryAccount.MBOX_QUOTA/1024,1) + ' MB)');
	}
    
	this.maintab.primary.description._value(this.__primaryAccount['DESCRIPTION']);
	this.maintab.primary.fullname._value(this.__primaryAccount['FULLNAME']);
	this.maintab.primary.alternative._value(this.__primaryAccount['ALTERNATIVE']);
	
	this.maintab.primary.x_last_time._value(this.__primaryAccount['LAST_TIME']);
	this.maintab.primary.x_last_ip._value(this.__primaryAccount['LAST_IP']);
};

_me.__saveItems = function() {
	var update = false;
	var accounts = new wm_accounts;
	var primary = {};

    if (GWOthers.getItem('RESTRICTIONS','disable_otheraccounts')!=1)
		for (var sEmail in this.__state) {
			var aValues = this.__otherAccounts[sEmail];
			switch (this.__state[sEmail]) {
				case 'edited':
					aValues['aid'] = sEmail;
				case 'new':
					update = true;

					accounts.add(aValues, 'folders','',[gui.frm_main,'_refreshItems',[sEmail]]);
					dataSet.add('accounts', [sEmail], aValues);

                    var value = gui.frm_main.folders._value();
                        value.push(sEmail);
                    gui.frm_main.folders._value(value);

					break;

				case 'deleted':
					accounts.remove({'aid':sEmail},'accounts','','folders');
					dataSet.remove('accounts',[sEmail]);
					update = true;
					break;

				default:
					continue;
			}
		}

	var desc = this.maintab.primary.description._value();
	if (desc != this.__primaryAccount['DESCRIPTION'])
		primary['DESCRIPTION'] = desc;

	var fname = this.maintab.primary.fullname._value();
	if (fname != this.__primaryAccount['FULLNAME'])
		primary['FULLNAME'] = fname;

	var alternative = this.maintab.primary.alternative._value();
	if (alternative != this.__primaryAccount['ALTERNATIVE'])
		primary['ALTERNATIVE'] = alternative;

	if (GWOthers.getItem('RESTRICTIONS','disable_changepass')!=1) {
		var pwd = this.maintab.primary.x_old_password._value();
	    var newpwd = this.maintab.primary.x_new_password._value();
	    var newpwdc = this.maintab.primary.x_new_password_conf._value();

		if (pwd || newpwd || newpwdc){
			if (!newpwd || newpwd != newpwdc){
				// TODO create some javascript alert window
				alert(getLang('ALERTS::INVALID_PASSWORD'));
				this.maintab.primary.x_old_password._focus();
				return false;
			}

			// encrypt password
			var rsa = new RSAKey();
			rsa.setPublic(auth.hashid({"username":this.__primaryAccount['USERNAME']}), '10001');

			primary['OLDPASSWORD'] = rsa.encrypt(pwd);
			primary['PASSWORD'] = rsa.encrypt(newpwd);
		}
	}

	if (count(primary) > 0){
		var aid = this.__primaryAccount['id'];

		for (var i in primary)
			dataSet.add('accounts', [aid,i], primary[i]);
			
		update = true;
		primary['aid'] = aid;

		accounts.add(primary, 'folders','',[this,'__save_handler']);
        this.x_btn_ok._disabled(true);
		return false;
	}

	if (update)
		gui.frm_main.folders._fill();

	return true;
};

_me.__save_handler = function (error){
	if (error){
		switch (error){
		case 'account_password_policy':
			alert(getLang('ALERTS::PASSWORD_POLICY'));
			break;
		default:
			alert(getLang('ALERTS::INVALID_PASSWORD'));
		}

		this.x_btn_ok._disabled(false);
	}
	else{
		gui.frm_main.folders._fill();
		this._destruct();
	}
};

_me.__onOtherAccEdit = function(aValues, sAccountID) {
	if (sAccountID) {
		for (var i in aValues){
			if (i == 'PASSWORD' && aValues[i] == '')
			    continue;
			
			this.__otherAccounts[sAccountID][i] = aValues[i];
		}
			
		if (this.__state[sAccountID] != 'new')
			this.__state[sAccountID] = 'edited';
	}
};

_me.__onOtherAccAdd = function(aValues) {
	var sAccountID = aValues['EMAIL'];
	if (!sAccountID)
		return;

	this.__otherAccounts[sAccountID] = aValues;

	if (this.__state[sAccountID] && this.__state[sAccountID] != 'new')
		this.__state[sAccountID] = 'edited';
	else
		this.__state[sAccountID] = 'new';

	this.maintab.other.x_accountslist._add([{'uid':sAccountID,'account':sAccountID}]);
};
